#
# spec file for package perl-Test-Differences
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Test-Differences
Name:           perl-Test-Differences
Version:        0.710.0
Release:        2.2
%define cpan_version 0.71
#Upstream:  All Rights Reserved. You may use, distribute and modify this software under the terms of the GNU public license, any version, or the Artistic license.
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Test strings and data structures and show differences if not ok
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DC/DCANTRELL/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Capture::Tiny) >= 0.24
BuildRequires:  perl(Data::Dumper) >= 2.126
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Text::Diff) >= 1.43
Requires:       perl(Capture::Tiny) >= 0.24
Requires:       perl(Data::Dumper) >= 2.126
Requires:       perl(Test::More) >= 0.88
Requires:       perl(Text::Diff) >= 1.43
Provides:       perl(Test::Differences) = 0.710.0
%undefine       __perllib_provides
%{perl_requires}

%description
When the code you're testing returns multiple lines, records or data
structures and they're just plain wrong, an equivalent to the Unix 'diff'
utility may be just what's needed. Here's output from an example test
script that checks two text documents and then two (trivial) data
structures:

 t/99example....1..3
 not ok 1 - differences in text
 #     Failed test ((eval 2) at line 14)
 #     +---+----------------+----------------+
 #     | Ln|Got             |Expected        |
 #     +---+----------------+----------------+
 #     |  1|this is line 1  |this is line 1  |
 #     *  2|this is line 2  |this is line b  *
 #     |  3|this is line 3  |this is line 3  |
 #     +---+----------------+----------------+
 not ok 2 - differences in whitespace
 #     Failed test ((eval 2) at line 20)
 #     +---+------------------+------------------+
 #     | Ln|Got               |Expected          |
 #     +---+------------------+------------------+
 #     |  1|        indented  |        indented  |
 #     *  2|        indented  |\tindented        *
 #     |  3|        indented  |        indented  |
 #     +---+------------------+------------------+
 not ok 3
 #     Failed test ((eval 2) at line 22)
 #     +----+-------------------------------------+----------------------------+
 #     | Elt|Got                                  |Expected                    |
 #     +----+-------------------------------------+----------------------------+
 #     *   0|bless( [                             |[                           *
 #     *   1|  'Move along, nothing to see here'  |  'Dry, humorless message'  *
 #     *   2|], 'Test::Builder' )                 |]                           *
 #     +----+-------------------------------------+----------------------------+
 # Looks like you failed 3 tests of 3.

eq_or_diff_...() compares two strings or (limited) data structures and
either emits an ok indication or a side-by-side diff. Test::Differences is
designed to be used with Test.pm and with Test::Simple, Test::More, and
other Test::Builder based testing modules. As the SYNOPSIS shows, another
testing module must be used as the basis for your test suite.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Fri Oct 13 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.71
  see /usr/share/doc/packages/perl-Test-Differences/Changes
  0.71   2023-10-12
  - Document and test different behaviour regarding Booleans in perl
    5.38.0 compared to earlier versions.
    See https://github.com/DrHyde/perl-modules-Test-Differences/issues/21
* Sat Jul  8 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.70
  see /usr/share/doc/packages/perl-Test-Differences/Changes
  0.70   2023-07-07
  - Stop pointless use of taint-mode in tests, so tests pass when perl is
    built without taint support
* Sat Jan  8 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.69
  see /usr/share/doc/packages/perl-Test-Differences/Changes
  0.69   2022-01-07
  - Special-case Unknown::Values objects in comparisons, as it's better to spit
    out a diagnostic failure than to just die;
  - Correct misleading Unicode doco
* Wed May 19 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.68
  see /usr/share/doc/packages/perl-Test-Differences/Changes
  0.68   2021-05-18
  - Revert undocumented change that was causing unreasonably verbose output
    See https://github.com/DrHyde/perl-modules-Test-Differences/issues/5
  - Improve documentation about text vs data mode and eq_or_diff_{text,data}
    See https://github.com/DrHyde/perl-modules-Test-Differences/issues/8
* Thu Mar  7 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- updated to 0.65
  see /usr/share/doc/packages/perl-Test-Differences/Changes
  0.67   2019-03-06
  - Correctly compare subroutine references
  0.66   2019-02-27
  - Fix tests on Windows (thanks to Serguei Trouchelle)
* Thu Feb 21 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Added test dependencies during build:
  * Test::Pod >= 1.22, Test::Pod::Coverage >= 1.08
- Cleaned with spec-cleaner
* Wed Feb 20 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.65
  see /usr/share/doc/packages/perl-Test-Differences/Changes
  0.65   2019-02-19
  - Canonical repo is now https://github.com/DrHyde/perl-modules-Test-Differences
  - Fix discrepancies in copyright notices (thanks to Christian Neukirchen
    for pointing them out)
  - Make the tests more consistent (thanks to genio)
  - Add unicode tests
  - Fix whitespace issue in tests when using recent Test::More in verbose mode
    (thanks to ntnyi for debugging)
  - Get rid of Build.PL, just use Makefile.PL
* Fri Nov 27 2015 coolo@suse.com
- updated to 0.64
  see /usr/share/doc/packages/perl-Test-Differences/Changes
  0.64 Sun November 22, 2015
  - Bump dependency version for Text::Diff to avoid a buggy release
  - Make tests pass with relocation perl (see
    https://rt.cpan.org/Ticket/Display.html?id=103133)
* Sat Feb  7 2015 coolo@suse.com
- updated to 0.63
  - Minor doco-fixes
  - Remove use of flatten, always use Data::Dumper for saner, more readable
    output, fixes RT #95446 (David Precious (bigpresh))
* Mon Sep 15 2014 coolo@suse.com
- updated to 0.62
  - Document the Text::Diff unicode fix.
  - Add ability to customise 'Got' and 'Expected' column headers
* Tue Dec 27 2011 coolo@suse.com
- fix typo in provide
* Sun Nov 20 2011 coolo@suse.com
- update to 0.61
  - Allow an option to override Sortkeys in C<eq_or_diff>. Thanks to Mark
    Zealey for the suggestion.
  - Unnumbered tests. There's no point to them.
  - Make '' and undef not equal. Thanks to Pavel Shaydo for the patch.
  - Made Data::Dumper minimum version 2.126 to resolve
    https://rt.cpan.org/Ticket/Display.html?id=60798. Thanks to
    jjnapiork@cpan.org  for the report and fix.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Jul 25 2010 pascal.bleser@opensuse.org
- initial package (0.500)
